import { primitive, Classy, TypeGuard } from "./types";
/**
 * Type guard for `boolean`.
 *
 * @param x
 */
export declare function isBoolean(x: any): x is boolean;
/**
 * Type guard for `number`.
 *
 * @param x
 */
export declare function isNumber(x: any): x is number;
/**
 * Type guard for `string`.
 *
 * @param x
 */
export declare function isString(x: any): x is string;
/**
 * Type guard for `symbol`.
 *
 * @param x
 */
export declare function isSymbol(x: any): x is symbol;
/**
 * Type guard for `null`.
 *
 * @param x
 */
export declare function isNull(x: any): x is null;
/**
 * Type guard for `undefined`.
 *
 * @param x
 */
export declare function isUndefined(x: any): x is undefined;
/**
 * Determines if something is a primitive.
 *
 * @param x
 *
 * @return `true` iff `x` is a `boolean`, `number`, `string`, `symbol`, `null`, or `undefined`.
 */
export declare function isPrimitive(x: any): x is primitive;
/**
 * Determines if something is not a primitive.
 *
 * @param x
 *
 * @return `true` iff `x` is not a primitive.
 */
export declare function isNonPrimitive(x: any): x is object;
/**
 * Curried type guard for non-primitive types.
 *
 * @param type The class to create a type guard for.
 *
 * @return A type guard which returns `true` iff its argument `x` satisfies `x instanceof type`.
 */
export declare function is<T>(type: Classy<T>): TypeGuard<T>;
/**
 * Curried type guard for checking if something is like something else, i.e. of the same type or a subtype.
 *
 * @param reference An object to use as reference for the type guard.
 *
 * @return A type guard which returns `true` iff its argument is of the same type as `reference` or is an instance of that type.
 */
export declare function isLike<T>(reference: T): TypeGuard<T>;
